@@ -4,6 +4,8 @@
 import numpy as _np
 import copy as _copy
 
+from ..backends import backend_module
+from ..backends import preferred_backend
 from .. import shtools as _shtools
 
 from .shcoeffs import SHCoeffs
@@ -27,6 +29,7 @@ class SlepianCoeffs(object):
     galpha          : A Slepian class instance that contains the associated
                       Slepian functions.
     nmax            : The number of Slepian expansion coefficients.
+    name            : The name of the dataset.
 
     Each class instance provides the following methods:
 
@@ -40,7 +43,7 @@ class SlepianCoeffs(object):
     info()          : Print a summary of the data stored in the SlepianCoeffs
                       instance.
 """
-    def __init__(self, falpha, galpha, copy=True):
+    def __init__(self, falpha, galpha, name=None, copy=True):
         """
         Initialize the SlepianCoeffs class.
         """
@@ -52,6 +55,7 @@ class SlepianCoeffs(object):
             self.galpha = galpha
 
         self.nmax = len(self.falpha)
+        self.name = name
 
     def copy(self):
         """
@@ -76,11 +80,13 @@ class SlepianCoeffs(object):
     def __repr__(self):
         str = ('nmax = {:d}\n'
                'lmax = {:d}\n'
-               .format(self.nmax, self.galpha.lmax))
+               'name = {:s}\n'
+               .format(self.nmax, self.galpha.lmax, repr(self.name)))
         str += '\nSlepian functions:\n' + self.galpha.__repr__()
         return str
 
-    def expand(self, nmax=None, grid='DH2', zeros=None, extend=True):
+    def expand(self, nmax=None, grid='DH2', zeros=None, extend=True,
+               backend=None, nthreads=None):
         """
         Expand the function on a grid using the first n Slepian coefficients.
 
@@ -107,6 +113,12 @@ class SlepianCoeffs(object):
         extend : bool, optional, default = True
             If True, compute the longitudinal band for 360 E (DH and GLQ grids)
             and the latitudinal band for 90 S (DH grids only).
+        backend : str, optional, default = preferred_backend()
+            Name of the preferred backend, either 'shtools' or 'ducc'.
+        nthreads : int, optional, default = 1
+            Number of threads to use for the 'ducc' backend. Setting this
+            parameter to 0 will use as many threads as there are hardware
+            threads on the system.
         """
         if type(grid) != str:
             raise ValueError('grid must be a string. ' +
@@ -115,6 +127,8 @@ class SlepianCoeffs(object):
 
         if nmax is None:
             nmax = self.nmax
+        if backend is None:
+            backend = preferred_backend()
 
         if self.galpha.kind == 'cap':
             shcoeffs = _shtools.SlepianCoeffsToSH(self.falpha,
@@ -124,18 +138,21 @@ class SlepianCoeffs(object):
                                                   self.galpha.tapers, nmax)
 
         if grid.upper() in ('DH', 'DH1'):
-            gridout = _shtools.MakeGridDH(shcoeffs, sampling=1,
-                                          norm=1, csphase=1, extend=extend)
+            gridout = backend_module(
+                backend=backend, nthreads=nthreads).MakeGridDH(
+                    shcoeffs, sampling=1, norm=1, csphase=1, extend=extend)
             return SHGrid.from_array(gridout, grid='DH', copy=False)
         elif grid.upper() == 'DH2':
-            gridout = _shtools.MakeGridDH(shcoeffs, sampling=2,
-                                          norm=1, csphase=1, extend=extend)
+            gridout = backend_module(
+                backend=backend, nthreads=nthreads).MakeGridDH(
+                    shcoeffs, sampling=2, norm=1, csphase=1, extend=extend)
             return SHGrid.from_array(gridout, grid='DH', copy=False)
         elif grid.upper() == 'GLQ':
-            if zeros is None:
+            if backend == "shtools" and zeros is None:
                 zeros, weights = _shtools.SHGLQ(self.galpha.lmax)
-            gridout = _shtools.MakeGridGLQ(shcoeffs, zeros, norm=1, csphase=1,
-                                           extend=extend)
+            gridout = backend_module(
+                backend=backend, nthreads=nthreads).MakeGridGLQ(
+                    shcoeffs, zeros=zeros, norm=1, csphase=1, extend=extend)
             return SHGrid.from_array(gridout, grid='GLQ', copy=False)
         else:
             raise ValueError(
@@ -259,7 +276,7 @@ class SlepianCoeffs(object):
         ax : matplotlib axes object, optional, default = None
             A single matplotlib axes object where the plot will appear.
         fname : str, optional, default = None
-            If present, and if axes is not specified, save the image to the
+            If present, and if ax is not specified, save the image to the
             specified file.
         **kwargs : keyword arguments, optional
             Keyword arguments for pyplot.plot().
